summaryrefslogtreecommitdiffstats
path: root/chrome/browser
diff options
context:
space:
mode:
authoravi@chromium.org <avi@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-12-14 21:11:32 +0000
committeravi@chromium.org <avi@chromium.org@0039d316-1c4b-4281-b951-d872f2087c98>2012-12-14 21:11:32 +0000
commit371d64ad1a0f5672f6ca396dfcd66c723926db97 (patch)
tree8b369e640bfd31f02c994772f1a19d9683837dd3 /chrome/browser
parent8ce34b4642c675a0ba0787d8f21f16bafa05e869 (diff)
downloadchromium_src-371d64ad1a0f5672f6ca396dfcd66c723926db97.zip
chromium_src-371d64ad1a0f5672f6ca396dfcd66c723926db97.tar.gz
chromium_src-371d64ad1a0f5672f6ca396dfcd66c723926db97.tar.bz2
Remove straggling TabContents references.
BUG=107201 TEST=no visible change Review URL: https://codereview.chromium.org/11577020 git-svn-id: svn://svn.chromium.org/chrome/trunk/src@173207 0039d316-1c4b-4281-b951-d872f2087c98
Diffstat (limited to 'chrome/browser')
-rw-r--r--chrome/browser/android/chrome_startup_flags.cc2
-rw-r--r--chrome/browser/automation/automation_tab_helper.h4
-rw-r--r--chrome/browser/automation/mock_tab_event_observer.h4
-rw-r--r--chrome/browser/bookmarks/bookmark_extension_api.cc2
-rw-r--r--chrome/browser/captive_portal/captive_portal_browsertest.cc4
-rw-r--r--chrome/browser/download/download_danger_prompt.h2
-rw-r--r--chrome/browser/external_protocol/external_protocol_handler.h2
-rw-r--r--chrome/browser/favicon/favicon_handler.h1
-rw-r--r--chrome/browser/favicon/favicon_handler_unittest.cc8
-rw-r--r--chrome/browser/file_select_helper.h2
-rw-r--r--chrome/browser/geolocation/chrome_geolocation_permission_context.cc2
-rw-r--r--chrome/browser/google/google_url_tracker.h4
-rw-r--r--chrome/browser/infobars/infobar_container.cc1
-rw-r--r--chrome/browser/password_manager/password_manager_delegate.h2
-rw-r--r--chrome/browser/printing/print_dialog_cloud_unittest.cc5
-rw-r--r--chrome/browser/printing/print_preview_tab_controller_unittest.cc26
-rw-r--r--chrome/browser/safe_browsing/client_side_detection_host.cc2
-rw-r--r--chrome/browser/safe_browsing/malware_details_history.h2
-rw-r--r--chrome/browser/sessions/session_service.h1
-rw-r--r--chrome/browser/tab_contents/retargeting_details.h2
-rw-r--r--chrome/browser/tab_contents/web_drag_bookmark_handler_gtk.cc2
-rw-r--r--chrome/browser/translate/translate_manager.h2
-rw-r--r--chrome/browser/ui/blocked_content/blocked_content_container.h4
-rw-r--r--chrome/browser/ui/blocked_content/blocked_content_tab_helper.h2
-rw-r--r--chrome/browser/ui/browser.h2
-rw-r--r--chrome/browser/ui/browser_command_controller.h1
-rw-r--r--chrome/browser/ui/browser_dialogs.h3
-rw-r--r--chrome/browser/ui/browser_tabstrip.h3
-rw-r--r--chrome/browser/ui/constrained_window_tab_helper_delegate.h2
-rw-r--r--chrome/browser/ui/find_bar/find_bar_controller.cc2
-rw-r--r--chrome/browser/ui/find_bar/find_bar_controller.h2
-rw-r--r--chrome/browser/ui/find_bar/find_bar_host_browsertest.cc2
-rw-r--r--chrome/browser/ui/intents/web_intent_picker_controller.h7
-rw-r--r--chrome/browser/ui/metro_pin_tab_helper_win.h2
-rw-r--r--chrome/browser/ui/search/search_delegate.h2
-rw-r--r--chrome/browser/ui/search_engines/template_url_fetcher_ui_callbacks.h2
-rw-r--r--chrome/browser/ui/startup/startup_browser_creator.h1
-rw-r--r--chrome/browser/ui/unload_controller.h1
-rw-r--r--chrome/browser/ui/views/frame/browser_view.h1
-rw-r--r--chrome/browser/ui/webui/test_chrome_web_ui_controller_factory.h8
40 files changed, 59 insertions, 70 deletions
diff --git a/chrome/browser/android/chrome_startup_flags.cc b/chrome/browser/android/chrome_startup_flags.cc
index 90b7f0a..7acfa16 100644
--- a/chrome/browser/android/chrome_startup_flags.cc
+++ b/chrome/browser/android/chrome_startup_flags.cc
@@ -33,7 +33,7 @@ void SetCommandLineSwitchASCII(const std::string& switch_string,
void SetChromeSpecificCommandLineFlags() {
// Turn on autofill.
// TODO(nileshagrawal): Remove this flag once Android stops relying on
- // tab_contents.cc.
+ // tab_contents.cc. http://crbug.com/153587
SetCommandLineSwitch(switches::kEnableNewAutofillUi);
// Turn on autologin.
diff --git a/chrome/browser/automation/automation_tab_helper.h b/chrome/browser/automation/automation_tab_helper.h
index 94dcb48..fd30442 100644
--- a/chrome/browser/automation/automation_tab_helper.h
+++ b/chrome/browser/automation/automation_tab_helper.h
@@ -34,11 +34,11 @@ class TabEventObserver {
// TODO(kkania): Track other types of scheduled navigations.
// Called when the tab that had no pending loads now has a new pending
- // load. |tab_contents| will always be valid.
+ // load. |web_contents| will always be valid.
virtual void OnFirstPendingLoad(content::WebContents* web_contents) { }
// Called when the tab that had one or more pending loads now has no
- // pending loads. |tab_contents| will always be valid.
+ // pending loads. |web_contents| will always be valid.
//
// This method will always be called if |OnFirstPendingLoad| was called.
virtual void OnNoMorePendingLoads(content::WebContents* web_contents) { }
diff --git a/chrome/browser/automation/mock_tab_event_observer.h b/chrome/browser/automation/mock_tab_event_observer.h
index 232ae92..4855029 100644
--- a/chrome/browser/automation/mock_tab_event_observer.h
+++ b/chrome/browser/automation/mock_tab_event_observer.h
@@ -19,8 +19,8 @@ class MockTabEventObserver : public TabEventObserver {
void StartObserving(AutomationTabHelper* tab_helper);
void StopObserving(AutomationTabHelper* tab_helper);
- MOCK_METHOD1(OnFirstPendingLoad, void(content::WebContents* tab_contents));
- MOCK_METHOD1(OnNoMorePendingLoads, void(content::WebContents* tab_contents));
+ MOCK_METHOD1(OnFirstPendingLoad, void(content::WebContents* web_contents));
+ MOCK_METHOD1(OnNoMorePendingLoads, void(content::WebContents* web_contents));
private:
DISALLOW_COPY_AND_ASSIGN(MockTabEventObserver);
diff --git a/chrome/browser/bookmarks/bookmark_extension_api.cc b/chrome/browser/bookmarks/bookmark_extension_api.cc
index c459057..f23d625 100644
--- a/chrome/browser/bookmarks/bookmark_extension_api.cc
+++ b/chrome/browser/bookmarks/bookmark_extension_api.cc
@@ -899,7 +899,7 @@ void BookmarksIOFunction::ShowSelectFileDialog(ui::SelectFileDialog::Type type,
// on for saving once Google Drive client on ChromeOS supports it.
if (type == ui::SelectFileDialog::SELECT_OPEN_FILE)
file_type_info.support_gdata = true;
- // |tab_contents| can be NULL (for background pages), which is fine. In such
+ // |web_contents| can be NULL (for background pages), which is fine. In such
// a case if file-selection dialogs are forbidden by policy, we will not
// show an InfoBar, which is better than letting one appear out of the blue.
select_file_dialog_->SelectFile(type,
diff --git a/chrome/browser/download/download_danger_prompt.h b/chrome/browser/download/download_danger_prompt.h
index d16820b..f63e0dc 100644
--- a/chrome/browser/download/download_danger_prompt.h
+++ b/chrome/browser/download/download_danger_prompt.h
@@ -32,7 +32,7 @@ class DownloadDangerPrompt {
// Return a new self-deleting DownloadDangerPrompt. |accepted| or |canceled|
// will be run when the the respective action is invoked. |canceled| may also
// be called when |item| is either no longer dangerous or no longer in
- // progress, or if the tab corresponding to |tab_contents| is
+ // progress, or if the tab corresponding to |web_contents| is
// closing. The returned DownloadDangerPrompt* is only used for testing. The
// caller does not own the object and receive no guarantees about lifetime.
static DownloadDangerPrompt* Create(
diff --git a/chrome/browser/external_protocol/external_protocol_handler.h b/chrome/browser/external_protocol/external_protocol_handler.h
index 96feca9..2cab580 100644
--- a/chrome/browser/external_protocol/external_protocol_handler.h
+++ b/chrome/browser/external_protocol/external_protocol_handler.h
@@ -66,7 +66,7 @@ class ExternalProtocolHandler {
// Creates and runs a External Protocol dialog box.
// |url| - The url of the request.
// |render_process_host_id| and |routing_id| are used by
- // tab_util::GetTabContentsByID to aquire the tab contents associated with
+ // tab_util::GetWebContentsByID to aquire the tab contents associated with
// this dialog.
// NOTE: There is a race between the Time of Check and the Time Of Use for
// the command line. Since the caller (web page) does not have access
diff --git a/chrome/browser/favicon/favicon_handler.h b/chrome/browser/favicon/favicon_handler.h
index a7ba7aa..e415bc7 100644
--- a/chrome/browser/favicon/favicon_handler.h
+++ b/chrome/browser/favicon/favicon_handler.h
@@ -254,7 +254,6 @@ class FaviconHandler {
GURL url_;
// Whether we got the initial response for the favicon back from the renderer.
- // See "Favicon Details" in tab_contents.cc for more details.
bool got_favicon_from_history_;
// Whether the favicon is out of date or the favicon data in
diff --git a/chrome/browser/favicon/favicon_handler_unittest.cc b/chrome/browser/favicon/favicon_handler_unittest.cc
index 5fc200f..8233e96 100644
--- a/chrome/browser/favicon/favicon_handler_unittest.cc
+++ b/chrome/browser/favicon/favicon_handler_unittest.cc
@@ -167,8 +167,8 @@ class HistoryRequestHandler {
// of subclassing.
class TestFaviconHandlerDelegate : public FaviconHandlerDelegate {
public:
- explicit TestFaviconHandlerDelegate(WebContents* tab_contents)
- : tab_contents_(tab_contents) {
+ explicit TestFaviconHandlerDelegate(WebContents* web_contents)
+ : web_contents_(web_contents) {
}
virtual NavigationEntry* GetActiveEntry() {
@@ -184,11 +184,11 @@ class TestFaviconHandlerDelegate : public FaviconHandlerDelegate {
}
virtual void NotifyFaviconUpdated() {
- tab_contents_->NotifyNavigationStateChanged(content::INVALIDATE_TYPE_TAB);
+ web_contents_->NotifyNavigationStateChanged(content::INVALIDATE_TYPE_TAB);
}
private:
- WebContents* tab_contents_; // weak
+ WebContents* web_contents_; // weak
};
// This class is used to catch the FaviconHandler's download and history
diff --git a/chrome/browser/file_select_helper.h b/chrome/browser/file_select_helper.h
index 5fe8a38..f85b9da 100644
--- a/chrome/browser/file_select_helper.h
+++ b/chrome/browser/file_select_helper.h
@@ -72,7 +72,7 @@ class FileSelectHelper
};
void RunFileChooser(content::RenderViewHost* render_view_host,
- content::WebContents* tab_contents,
+ content::WebContents* web_contents,
const content::FileChooserParams& params);
void RunFileChooserOnFileThread(
const content::FileChooserParams& params);
diff --git a/chrome/browser/geolocation/chrome_geolocation_permission_context.cc b/chrome/browser/geolocation/chrome_geolocation_permission_context.cc
index 2d4ba1c..12065c1 100644
--- a/chrome/browser/geolocation/chrome_geolocation_permission_context.cc
+++ b/chrome/browser/geolocation/chrome_geolocation_permission_context.cc
@@ -81,7 +81,7 @@ void ChromeGeolocationPermissionContext::RequestGeolocationPermission(
if (chrome::GetViewType(web_contents) != chrome::VIEW_TYPE_TAB_CONTENTS) {
// The tab may have gone away, or the request may not be from a tab at all.
// TODO(mpcomplete): the request could be from a background page or
- // extension popup (tab_contents will have a different ViewType). But why do
+ // extension popup (web_contents will have a different ViewType). But why do
// we care? Shouldn't we still put an infobar up in the current tab?
LOG(WARNING) << "Attempt to use geolocation tabless renderer: "
<< id.ToString()
diff --git a/chrome/browser/google/google_url_tracker.h b/chrome/browser/google/google_url_tracker.h
index ef1f0d8..7b95c56 100644
--- a/chrome/browser/google/google_url_tracker.h
+++ b/chrome/browser/google/google_url_tracker.h
@@ -139,8 +139,8 @@ class GoogleURLTracker : public net::URLFetcherDelegate,
// Called by Observe() after SearchCommitted() registers notification
// listeners, to indicate that we've received the "load now pending"
// notification. |navigation_controller_source| and |web_contents_source| are
- // NotificationSources pointing to the associated NavigationController and
- // TabContents, respectively, for this load; |infobar_helper| is the
+ // the NotificationSource pointing to the associated NavigationController and
+ // the WebContents, respectively, for this load; |infobar_helper| is the
// InfoBarTabHelper of the associated tab; and |pending_id| is the unique ID
// of the newly pending NavigationEntry. If there is already a visible
// GoogleURLTracker infobar for this tab, this function resets its associated
diff --git a/chrome/browser/infobars/infobar_container.cc b/chrome/browser/infobars/infobar_container.cc
index 907af0a..6bc2069 100644
--- a/chrome/browser/infobars/infobar_container.cc
+++ b/chrome/browser/infobars/infobar_container.cc
@@ -121,7 +121,6 @@ void InfoBarContainer::RemoveAllInfoBarsForDestruction() {
// and at worst disastrous to call that.
delegate_ = NULL;
- // TODO(pkasting): Remove this once TabContents calls CloseSoon().
for (size_t i = infobars_.size(); i > 0; --i)
infobars_[i - 1]->CloseSoon();
diff --git a/chrome/browser/password_manager/password_manager_delegate.h b/chrome/browser/password_manager/password_manager_delegate.h
index e3314ba..6eef057 100644
--- a/chrome/browser/password_manager/password_manager_delegate.h
+++ b/chrome/browser/password_manager/password_manager_delegate.h
@@ -18,7 +18,7 @@ class PasswordManagerDelegate {
PasswordManagerDelegate() {}
virtual ~PasswordManagerDelegate() {}
- // Fill forms matching |form_data| in |tab_contents|. By default, goes
+ // Fill forms matching |form_data| in |web_contents|. By default, goes
// through the RenderViewHost to FillPasswordForm. Tests can override this
// to sever the dependency on the entire rendering stack.
virtual void FillPasswordForm(
diff --git a/chrome/browser/printing/print_dialog_cloud_unittest.cc b/chrome/browser/printing/print_dialog_cloud_unittest.cc
index 3163f99..9e976c9 100644
--- a/chrome/browser/printing/print_dialog_cloud_unittest.cc
+++ b/chrome/browser/printing/print_dialog_cloud_unittest.cc
@@ -355,8 +355,7 @@ TEST_F(CloudPrintWebDialogDelegateTest, UnownedFlowLetGo) {
EXPECT_THAT(mock_flow_handler_.get(), NotNull());
}
-// Testing for ExternalWebDialogUI needs a mock WebContents, mock
-// CloudPrintWebDialogDelegate (provided through the mock
-// tab_contents)
+// Testing for ExternalWebDialogUI needs a mock WebContents and mock
+// CloudPrintWebDialogDelegate (attached to the mock web_contents).
// Testing for PrintDialogCloud needs a mock Browser.
diff --git a/chrome/browser/printing/print_preview_tab_controller_unittest.cc b/chrome/browser/printing/print_preview_tab_controller_unittest.cc
index 4500875..35a026e 100644
--- a/chrome/browser/printing/print_preview_tab_controller_unittest.cc
+++ b/chrome/browser/printing/print_preview_tab_controller_unittest.cc
@@ -76,14 +76,14 @@ TEST_F(PrintPreviewTabControllerUnitTest, MAYBE_MultiplePreviewTabs) {
EXPECT_EQ(0, browser()->tab_count());
chrome::NewTab(browser());
- WebContents* tab_contents_1 =
+ WebContents* web_contents_1 =
browser()->tab_strip_model()->GetActiveWebContents();
- ASSERT_TRUE(tab_contents_1);
+ ASSERT_TRUE(web_contents_1);
chrome::NewTab(browser());
- WebContents* tab_contents_2 =
+ WebContents* web_contents_2 =
browser()->tab_strip_model()->GetActiveWebContents();
- ASSERT_TRUE(tab_contents_2);
+ ASSERT_TRUE(web_contents_2);
EXPECT_EQ(2, browser()->tab_count());
printing::PrintPreviewTabController* tab_controller =
@@ -91,21 +91,21 @@ TEST_F(PrintPreviewTabControllerUnitTest, MAYBE_MultiplePreviewTabs) {
ASSERT_TRUE(tab_controller);
// Create preview tab for |tab_contents_1|
- printing::PrintViewManager::FromWebContents(tab_contents_1)->
+ printing::PrintViewManager::FromWebContents(web_contents_1)->
PrintPreviewNow();
WebContents* preview_tab_1 =
- tab_controller->GetOrCreatePreviewTab(tab_contents_1);
+ tab_controller->GetOrCreatePreviewTab(web_contents_1);
- EXPECT_NE(tab_contents_1, preview_tab_1);
+ EXPECT_NE(web_contents_1, preview_tab_1);
EXPECT_EQ(2, browser()->tab_count());
// Create preview tab for |tab_contents_2|
- printing::PrintViewManager::FromWebContents(tab_contents_2)->
+ printing::PrintViewManager::FromWebContents(web_contents_2)->
PrintPreviewNow();
WebContents* preview_tab_2 =
- tab_controller->GetOrCreatePreviewTab(tab_contents_2);
+ tab_controller->GetOrCreatePreviewTab(web_contents_2);
- EXPECT_NE(tab_contents_2, preview_tab_2);
+ EXPECT_NE(web_contents_2, preview_tab_2);
// 2 initiator tab and 2 preview tabs exist in the same browser.
// The preview tabs are constrained in their respective initiator tabs.
EXPECT_EQ(2, browser()->tab_count());
@@ -113,8 +113,8 @@ TEST_F(PrintPreviewTabControllerUnitTest, MAYBE_MultiplePreviewTabs) {
TabStripModel* model = browser()->tab_strip_model();
ASSERT_TRUE(model);
- int tab_1_index = model->GetIndexOfWebContents(tab_contents_1);
- int tab_2_index = model->GetIndexOfWebContents(tab_contents_2);
+ int tab_1_index = model->GetIndexOfWebContents(web_contents_1);
+ int tab_2_index = model->GetIndexOfWebContents(web_contents_2);
int preview_tab_1_index = model->GetIndexOfWebContents(preview_tab_1);
int preview_tab_2_index = model->GetIndexOfWebContents(preview_tab_2);
@@ -124,7 +124,7 @@ TEST_F(PrintPreviewTabControllerUnitTest, MAYBE_MultiplePreviewTabs) {
// When we get the preview tab for |tab_contents_1|,
// |preview_tab_1| is activated and focused.
- tab_controller->GetOrCreatePreviewTab(tab_contents_1);
+ tab_controller->GetOrCreatePreviewTab(web_contents_1);
EXPECT_EQ(tab_1_index, browser()->active_index());
}
diff --git a/chrome/browser/safe_browsing/client_side_detection_host.cc b/chrome/browser/safe_browsing/client_side_detection_host.cc
index 8d1439c..ec43288 100644
--- a/chrome/browser/safe_browsing/client_side_detection_host.cc
+++ b/chrome/browser/safe_browsing/client_side_detection_host.cc
@@ -55,7 +55,7 @@ void EmptyUrlCheckCallback(bool processed) {
// asynchronously checks whether the phishing classifier should run for this
// URL. If so, it notifies the renderer with a StartPhishingDetection IPC.
// Objects of this class are ref-counted and will be destroyed once nobody
-// uses it anymore. If |tab_contents|, |csd_service| or |host| go away you need
+// uses it anymore. If |web_contents|, |csd_service| or |host| go away you need
// to call Cancel(). We keep the |database_manager| alive in a ref pointer for
// as long as it takes.
class ClientSideDetectionHost::ShouldClassifyUrlRequest
diff --git a/chrome/browser/safe_browsing/malware_details_history.h b/chrome/browser/safe_browsing/malware_details_history.h
index a146f12..9da77da 100644
--- a/chrome/browser/safe_browsing/malware_details_history.h
+++ b/chrome/browser/safe_browsing/malware_details_history.h
@@ -34,7 +34,7 @@ class MalwareDetailsRedirectsCollector
explicit MalwareDetailsRedirectsCollector(Profile* profile);
// Collects urls' redirects chain information from the history service.
- // We get access to history service via tab_contents in UI thread.
+ // We get access to history service via web_contents in UI thread.
// Notice the callback will be posted to the IO thread.
void StartHistoryCollection(const std::vector<GURL>& urls,
const base::Closure& callback);
diff --git a/chrome/browser/sessions/session_service.h b/chrome/browser/sessions/session_service.h
index 280a8e8..23b3adc 100644
--- a/chrome/browser/sessions/session_service.h
+++ b/chrome/browser/sessions/session_service.h
@@ -26,7 +26,6 @@
class Profile;
class SessionCommand;
-class TabContents;
struct SessionTab;
struct SessionWindow;
diff --git a/chrome/browser/tab_contents/retargeting_details.h b/chrome/browser/tab_contents/retargeting_details.h
index 4a5febc..ffbd274 100644
--- a/chrome/browser/tab_contents/retargeting_details.h
+++ b/chrome/browser/tab_contents/retargeting_details.h
@@ -25,7 +25,7 @@ struct RetargetingDetails {
// The target tab contents.
content::WebContents* target_web_contents;
- // True if the target_tab_contents is not yet inserted into a tab strip.
+ // True if the target_web_contents is not yet inserted into a tab strip.
bool not_yet_in_tabstrip;
};
diff --git a/chrome/browser/tab_contents/web_drag_bookmark_handler_gtk.cc b/chrome/browser/tab_contents/web_drag_bookmark_handler_gtk.cc
index 01e7659..e22fd1d 100644
--- a/chrome/browser/tab_contents/web_drag_bookmark_handler_gtk.cc
+++ b/chrome/browser/tab_contents/web_drag_bookmark_handler_gtk.cc
@@ -74,7 +74,7 @@ void WebDragBookmarkHandlerGtk::OnDragEnter() {
}
void WebDragBookmarkHandlerGtk::OnDrop() {
- // This is non-null if tab_contents_ is showing an ExtensionWebUI with
+ // This is non-null if web_contents_ is showing an ExtensionWebUI with
// support for (at the moment experimental) drag and drop extensions.
if (bookmark_tab_helper_) {
if (bookmark_tab_helper_->GetBookmarkDragDelegate()) {
diff --git a/chrome/browser/translate/translate_manager.h b/chrome/browser/translate/translate_manager.h
index b5a2174..2308267 100644
--- a/chrome/browser/translate/translate_manager.h
+++ b/chrome/browser/translate/translate_manager.h
@@ -151,7 +151,7 @@ class TranslateManager : public content::NotificationObserver,
int render_id,
const std::string& page_lang);
- // Sends a translation request to the RenderView of |tab_contents|.
+ // Sends a translation request to the RenderView of |web_contents|.
void DoTranslatePage(content::WebContents* web_contents,
const std::string& translate_script,
const std::string& source_lang,
diff --git a/chrome/browser/ui/blocked_content/blocked_content_container.h b/chrome/browser/ui/blocked_content/blocked_content_container.h
index c491d1b..51e5ce1 100644
--- a/chrome/browser/ui/blocked_content/blocked_content_container.h
+++ b/chrome/browser/ui/blocked_content/blocked_content_container.h
@@ -21,7 +21,7 @@ namespace content {
class WebContents;
}
-// Takes ownership of TabContentses that are unrequested popup windows.
+// Takes ownership of WebContentses that are unrequested popup windows.
class BlockedContentContainer : public BlockedContentTabHelperDelegate,
public content::WebContentsDelegate {
public:
@@ -30,7 +30,7 @@ class BlockedContentContainer : public BlockedContentTabHelperDelegate,
virtual ~BlockedContentContainer();
// Adds a WebContents to this container. |bounds| are the window bounds
- // requested for the TabContents.
+ // requested for the WebContents.
void AddWebContents(content::WebContents* web_contents,
WindowOpenDisposition disposition,
const gfx::Rect& bounds,
diff --git a/chrome/browser/ui/blocked_content/blocked_content_tab_helper.h b/chrome/browser/ui/blocked_content/blocked_content_tab_helper.h
index f8107a0..9785599 100644
--- a/chrome/browser/ui/blocked_content/blocked_content_tab_helper.h
+++ b/chrome/browser/ui/blocked_content/blocked_content_tab_helper.h
@@ -74,7 +74,7 @@ class BlockedContentTabHelper
// Object that holds any blocked WebContentses spawned from this WebContents.
scoped_ptr<BlockedContentContainer> blocked_contents_;
- // Should we block all child TabContents this attempts to spawn.
+ // Should we block all child WebContentses this attempts to spawn.
bool all_contents_blocked_;
// Delegate for notifying our owner (usually Browser) about stuff. Not owned
diff --git a/chrome/browser/ui/browser.h b/chrome/browser/ui/browser.h
index 9fef239..b67dca3 100644
--- a/chrome/browser/ui/browser.h
+++ b/chrome/browser/ui/browser.h
@@ -715,7 +715,7 @@ class Browser : public TabStripModelObserver,
const base::Callback<void(bool)>& callback) OVERRIDE;
// Overridden from CoreTabHelperDelegate:
- // Note that the caller is responsible for deleting |old_tab_contents|.
+ // Note that the caller is responsible for deleting |old_contents|.
virtual void SwapTabContents(content::WebContents* old_contents,
content::WebContents* new_contents) OVERRIDE;
virtual bool CanReloadContents(
diff --git a/chrome/browser/ui/browser_command_controller.h b/chrome/browser/ui/browser_command_controller.h
index af6ef91..3f76188 100644
--- a/chrome/browser/ui/browser_command_controller.h
+++ b/chrome/browser/ui/browser_command_controller.h
@@ -18,7 +18,6 @@
class Browser;
class BrowserWindow;
class Profile;
-class TabContents;
namespace content {
struct NativeWebKeyboardEvent;
diff --git a/chrome/browser/ui/browser_dialogs.h b/chrome/browser/ui/browser_dialogs.h
index ab72fd0..8cff3b2 100644
--- a/chrome/browser/ui/browser_dialogs.h
+++ b/chrome/browser/ui/browser_dialogs.h
@@ -10,7 +10,6 @@
class Browser;
class SkBitmap;
-class TabContents;
class TabModalConfirmDialogDelegate;
namespace content {
@@ -67,7 +66,7 @@ void HideHungRendererDialog(content::WebContents* contents);
#if !defined(OS_MACOSX)
// Shows the create web app shortcut dialog box.
void ShowCreateWebAppShortcutsDialog(gfx::NativeWindow parent_window,
- content::WebContents* tab_contents);
+ content::WebContents* web_contents);
#endif
} // namespace chrome
diff --git a/chrome/browser/ui/browser_tabstrip.h b/chrome/browser/ui/browser_tabstrip.h
index 3602f64..893983d 100644
--- a/chrome/browser/ui/browser_tabstrip.h
+++ b/chrome/browser/ui/browser_tabstrip.h
@@ -13,7 +13,6 @@
class Browser;
class GURL;
class Profile;
-class TabContents;
namespace content {
class SiteInstance;
@@ -34,7 +33,7 @@ content::WebContents* GetWebContentsAt(const Browser* browser, int index);
void AddBlankTabAt(Browser* browser, int index, bool foreground);
// Adds a selected tab with the specified URL and transition, returns the
-// created TabContents.
+// created WebContents.
content::WebContents* AddSelectedTabWithURL(Browser* browser,
const GURL& url,
content::PageTransition transition);
diff --git a/chrome/browser/ui/constrained_window_tab_helper_delegate.h b/chrome/browser/ui/constrained_window_tab_helper_delegate.h
index 652e20a..8e426ee 100644
--- a/chrome/browser/ui/constrained_window_tab_helper_delegate.h
+++ b/chrome/browser/ui/constrained_window_tab_helper_delegate.h
@@ -18,7 +18,7 @@ class ConstrainedWindowTabHelperDelegate {
// Returns true if constrained windows should be focused. Default is true.
virtual bool ShouldFocusConstrainedWindow();
- // Changes the blocked state of |tab_contents|. WebContentses are considered
+ // Changes the blocked state of |web_contents|. WebContentses are considered
// blocked while displaying a tab modal dialog. During that time renderer host
// will ignore any UI interaction within WebContents outside of the
// currently displaying dialog.
diff --git a/chrome/browser/ui/find_bar/find_bar_controller.cc b/chrome/browser/ui/find_bar/find_bar_controller.cc
index 34337de..d71ddac 100644
--- a/chrome/browser/ui/find_bar/find_bar_controller.cc
+++ b/chrome/browser/ui/find_bar/find_bar_controller.cc
@@ -128,7 +128,7 @@ void FindBarController::Observe(int type,
FindTabHelper* find_tab_helper =
FindTabHelper::FromWebContents(web_contents_);
if (type == chrome::NOTIFICATION_FIND_RESULT_AVAILABLE) {
- // Don't update for notifications from TabContentses other than the one we
+ // Don't update for notifications from WebContentses other than the one we
// are actively tracking.
if (content::Source<WebContents>(source).ptr() == web_contents_) {
UpdateFindBarForCurrentResult();
diff --git a/chrome/browser/ui/find_bar/find_bar_controller.h b/chrome/browser/ui/find_bar/find_bar_controller.h
index 391014e..c73809f 100644
--- a/chrome/browser/ui/find_bar/find_bar_controller.h
+++ b/chrome/browser/ui/find_bar/find_bar_controller.h
@@ -76,7 +76,7 @@ class FindBarController : public content::NotificationObserver {
private:
// Sents an update to the find bar with the tab contents' current result. The
- // tab_contents_ must be non-NULL before this call. Theis handles
+ // web_contents_ must be non-NULL before this call. Theis handles
// de-flickering in addition to just calling the update function.
void UpdateFindBarForCurrentResult();
diff --git a/chrome/browser/ui/find_bar/find_bar_host_browsertest.cc b/chrome/browser/ui/find_bar/find_bar_host_browsertest.cc
index eb34f7b..59ae8f2 100644
--- a/chrome/browser/ui/find_bar/find_bar_host_browsertest.cc
+++ b/chrome/browser/ui/find_bar/find_bar_host_browsertest.cc
@@ -1106,7 +1106,7 @@ IN_PROC_BROWSER_TEST_F(FindInPageControllerTest, StayActive) {
// Simulate a user clearing the search string. Ideally, we should be
// simulating keypresses here for searching for something and pressing
// backspace, but that's been proven flaky in the past, so we go straight to
- // tab_contents.
+ // web_contents.
FindTabHelper* find_tab_helper = FindTabHelper::FromWebContents(
browser()->tab_strip_model()->GetActiveWebContents());
// Stop the (non-existing) find operation, and clear the selection (which
diff --git a/chrome/browser/ui/intents/web_intent_picker_controller.h b/chrome/browser/ui/intents/web_intent_picker_controller.h
index 43936ed..fb4f6ef 100644
--- a/chrome/browser/ui/intents/web_intent_picker_controller.h
+++ b/chrome/browser/ui/intents/web_intent_picker_controller.h
@@ -176,7 +176,7 @@ class WebIntentPickerController
picker_model_->set_observer(observer);
}
- // Notify the controller that its TabContents is hosting a web intents
+ // Notify the controller that its WebContents is hosting a web intents
// service. Sets the source and dispatcher for the invoking client.
void SetWindowDispositionSource(content::WebContents* source,
content::WebIntentsDispatcher* dispatcher);
@@ -294,9 +294,8 @@ class WebIntentPickerController
bool cancelled_;
#endif
- // Weak pointer to the source WebContents for the intent if the TabContents
- // with which this controller is associated is hosting a web intents window
- // disposition service.
+ // Weak pointer to the source WebContents for the intent if it is associated
+ // with this controller and hosting a web intents window disposition service.
content::WebContents* window_disposition_source_;
// If this tab is hosting a web intents service, a weak pointer to dispatcher
diff --git a/chrome/browser/ui/metro_pin_tab_helper_win.h b/chrome/browser/ui/metro_pin_tab_helper_win.h
index 63770ce..0ea7ff4 100644
--- a/chrome/browser/ui/metro_pin_tab_helper_win.h
+++ b/chrome/browser/ui/metro_pin_tab_helper_win.h
@@ -38,7 +38,7 @@ class MetroPinTabHelper
// continue on with the page pinning action.
class FaviconChooser;
- explicit MetroPinTabHelper(content::WebContents* tab_contents);
+ explicit MetroPinTabHelper(content::WebContents* web_contents);
friend class content::WebContentsUserData<MetroPinTabHelper>;
// Favicon download callback.
diff --git a/chrome/browser/ui/search/search_delegate.h b/chrome/browser/ui/search/search_delegate.h
index 0ab9076..f88e291 100644
--- a/chrome/browser/ui/search/search_delegate.h
+++ b/chrome/browser/ui/search/search_delegate.h
@@ -55,7 +55,7 @@ class SearchDelegate : public SearchModelObserver {
// propagated to the |browser_model_|.
SearchModel* browser_model_;
- // Weak. The TabContents owns this. It is the model of the active
+ // Weak. The WebContents owns this. It is the model of the active
// tab. Changes to this model are propagated through to the |browser_model_|.
SearchModel* tab_model_;
diff --git a/chrome/browser/ui/search_engines/template_url_fetcher_ui_callbacks.h b/chrome/browser/ui/search_engines/template_url_fetcher_ui_callbacks.h
index 6f44bec..905899a 100644
--- a/chrome/browser/ui/search_engines/template_url_fetcher_ui_callbacks.h
+++ b/chrome/browser/ui/search_engines/template_url_fetcher_ui_callbacks.h
@@ -22,7 +22,7 @@ class TemplateURLFetcherUICallbacks : public TemplateURLFetcherCallbacks,
public content::NotificationObserver {
public:
TemplateURLFetcherUICallbacks(SearchEngineTabHelper* tab_helper,
- content::WebContents* tab_contents);
+ content::WebContents* web_contents);
virtual ~TemplateURLFetcherUICallbacks();
// TemplateURLFetcherCallback implementation.
diff --git a/chrome/browser/ui/startup/startup_browser_creator.h b/chrome/browser/ui/startup/startup_browser_creator.h
index ea6b24f..034dc61 100644
--- a/chrome/browser/ui/startup/startup_browser_creator.h
+++ b/chrome/browser/ui/startup/startup_browser_creator.h
@@ -21,7 +21,6 @@ class Browser;
class CommandLine;
class GURL;
class PrefService;
-class TabContents;
// class containing helpers for BrowserMain to spin up a new instance and
// initialize the profile.
diff --git a/chrome/browser/ui/unload_controller.h b/chrome/browser/ui/unload_controller.h
index 73010ce..4c13c67 100644
--- a/chrome/browser/ui/unload_controller.h
+++ b/chrome/browser/ui/unload_controller.h
@@ -13,7 +13,6 @@
#include "content/public/browser/notification_registrar.h"
class Browser;
-class TabContents;
class TabStripModel;
namespace content {
diff --git a/chrome/browser/ui/views/frame/browser_view.h b/chrome/browser/ui/views/frame/browser_view.h
index 2f7da2f..7fa6ca9 100644
--- a/chrome/browser/ui/views/frame/browser_view.h
+++ b/chrome/browser/ui/views/frame/browser_view.h
@@ -50,7 +50,6 @@ class InstantPreviewControllerViews;
class LocationBarView;
class StatusBubbleViews;
class SearchViewController;
-class TabContents;
class TabStrip;
class TabStripModel;
class ToolbarView;
diff --git a/chrome/browser/ui/webui/test_chrome_web_ui_controller_factory.h b/chrome/browser/ui/webui/test_chrome_web_ui_controller_factory.h
index 99b26d3..627123d 100644
--- a/chrome/browser/ui/webui/test_chrome_web_ui_controller_factory.h
+++ b/chrome/browser/ui/webui/test_chrome_web_ui_controller_factory.h
@@ -2,8 +2,8 @@
// Use of this source code is governed by a BSD-style license that can be
// found in the LICENSE file.
-#ifndef CHROME_BROWSER_UI_WEBUI_TEST_CHROME_WEB_UI_FACTORY_H_
-#define CHROME_BROWSER_UI_WEBUI_TEST_CHROME_WEB_UI_FACTORY_H_
+#ifndef CHROME_BROWSER_UI_WEBUI_TEST_CHROME_WEB_UI_CONTROLLER_FACTORY_H_
+#define CHROME_BROWSER_UI_WEBUI_TEST_CHROME_WEB_UI_CONTROLLER_FACTORY_H_
#include <functional>
#include <map>
@@ -20,7 +20,7 @@ class TestChromeWebUIControllerFactory : public ChromeWebUIControllerFactory {
// Interface to create a new WebUI object.
class WebUIProvider {
public:
- // Create and return a new WebUI object for the |tab_contents| based on the
+ // Create and return a new WebUI object for the |web_contents| based on the
// |url|.
virtual content::WebUIController* NewWebUI(content::WebUI* web_ui,
const GURL& url) = 0;
@@ -63,4 +63,4 @@ class TestChromeWebUIControllerFactory : public ChromeWebUIControllerFactory {
DISALLOW_COPY_AND_ASSIGN(TestChromeWebUIControllerFactory);
};
-#endif // CHROME_BROWSER_UI_WEBUI_TEST_CHROME_WEB_UI_FACTORY_H_
+#endif // CHROME_BROWSER_UI_WEBUI_TEST_CHROME_WEB_UI_CONTROLLER_FACTORY_H_
diff --git a/chrome/browser/captive_portal/captive_portal_browsertest.cc b/chrome/browser/captive_portal/captive_portal_browsertest.cc
index 8ce5bbc..86172ef 100644
--- a/chrome/browser/captive_portal/captive_portal_browsertest.cc
+++ b/chrome/browser/captive_portal/captive_portal_browsertest.cc
@@ -812,9 +812,9 @@ class CaptivePortalBrowserTest : public InProcessBrowserTest {
// check.
bool CheckPending(Browser* browser);
// Returns the CaptivePortalTabReloader::State of |tab_contents|.
CaptivePortalTabReloader::State GetStateOfTabReloader(
- WebContents* tab_contents) const;
+ WebContents* web_contents) const;
// Returns the CaptivePortalTabReloader::State of the indicated tab.
CaptivePortalTabReloader::State GetStateOfTabReloaderAt(Browser* browser,
@@ -812,9 +812,9 @@ class CaptivePortalBrowserTest : public InProcessBrowserTest {
// check.
bool CheckPending(Browser* browser);
- // Returns the CaptivePortalTabReloader::State of |tab_contents|.
+ // Returns the CaptivePortalTabReloader::State of |web_contents|.
CaptivePortalTabReloader::State GetStateOfTabReloader(